package com.ruoyi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.TAutomobileEnterpriseMapper;
import com.ruoyi.domain.TAutomobileEnterprise;
import com.ruoyi.service.ITAutomobileEnterpriseService;

/**
 * 车企信息Service业务层处理
 *
 * @author gxk
 * @date 2024-01-05
 */
@Service
public class TAutomobileEnterpriseServiceImpl implements ITAutomobileEnterpriseService
{
    @Autowired
    private TAutomobileEnterpriseMapper tAutomobileEnterpriseMapper;

    /**
     * 查询车企信息
     *
     * @param id 车企信息主键
     * @return 车企信息
     */
    @Override
    public TAutomobileEnterprise selectTAutomobileEnterpriseById(Long id)
    {
        return tAutomobileEnterpriseMapper.selectTAutomobileEnterpriseById(id);
    }

    /**
     * 查询车企信息列表
     *
     * @param tAutomobileEnterprise 车企信息
     * @return 车企信息
     */
    @Override
    public List<TAutomobileEnterprise> selectTAutomobileEnterpriseList(TAutomobileEnterprise tAutomobileEnterprise)
    {
        return tAutomobileEnterpriseMapper.selectTAutomobileEnterpriseList(tAutomobileEnterprise);
    }

    /**
     * 新增车企信息
     *
     * @param tAutomobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int insertTAutomobileEnterprise(TAutomobileEnterprise tAutomobileEnterprise)
    {
        tAutomobileEnterprise.setCreateTime(DateUtils.getNowDate());
        tAutomobileEnterprise.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        return tAutomobileEnterpriseMapper.insertTAutomobileEnterprise(tAutomobileEnterprise);
    }

    /**
     * 修改车企信息
     *
     * @param tAutomobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int updateTAutomobileEnterprise(TAutomobileEnterprise tAutomobileEnterprise)
    {
        tAutomobileEnterprise.setUpdateTime(DateUtils.getNowDate());
        tAutomobileEnterprise.setUpdateBy(String.valueOf(SecurityUtils.getUserId()));
        return tAutomobileEnterpriseMapper.updateTAutomobileEnterprise(tAutomobileEnterprise);
    }

    /**
     * 批量删除车企信息
     *
     * @param ids 需要删除的车企信息主键
     * @return 结果
     */
    @Override
    public int deleteTAutomobileEnterpriseByIds(Long[] ids)
    {
        return tAutomobileEnterpriseMapper.deleteTAutomobileEnterpriseByIds(ids);
    }

    /**
     * 删除车企信息信息
     *
     * @param id 车企信息主键
     * @return 结果
     */
    @Override
    public int deleteTAutomobileEnterpriseById(Long id)
    {
        return tAutomobileEnterpriseMapper.deleteTAutomobileEnterpriseById(id);
    }
}
