package com.ruoyi.web;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.TAutomobileEnterprise;
import com.ruoyi.service.ITAutomobileEnterpriseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 车企信息Controller
 *
 * @author gxk
 * @date 2024-01-05
 */
@RestController
@RequestMapping("/system/enterprise")
public class TAutomobileEnterpriseController extends BaseController
{
    @Autowired
    private ITAutomobileEnterpriseService tAutomobileEnterpriseService;

    /**
     * 查询车企信息列表
     */
    @Anonymous
    @GetMapping("/list")
    public TableDataInfo list(TAutomobileEnterprise tAutomobileEnterprise)
    {
        startPage();
        List<TAutomobileEnterprise> list = tAutomobileEnterpriseService.selectTAutomobileEnterpriseList(tAutomobileEnterprise);
        return getDataTable(list);
    }

    /**
     * 导出车企信息列表
     */
    @Log(title = "车企信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TAutomobileEnterprise tAutomobileEnterprise)
    {
        List<TAutomobileEnterprise> list = tAutomobileEnterpriseService.selectTAutomobileEnterpriseList(tAutomobileEnterprise);
        ExcelUtil<TAutomobileEnterprise> util = new ExcelUtil<TAutomobileEnterprise>(TAutomobileEnterprise.class);
        util.exportExcel(response, list, "车企信息数据");
    }

    /**
     * 获取车企信息详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tAutomobileEnterpriseService.selectTAutomobileEnterpriseById(id));
    }

    /**
     * 新增车企信息
     */
    @Anonymous
    @Log(title = "车企信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAutomobileEnterprise tAutomobileEnterprise)
    {
        return toAjax(tAutomobileEnterpriseService.insertTAutomobileEnterprise(tAutomobileEnterprise));
    }

    /**
     * 修改车企信息
     */
    @Log(title = "车企信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAutomobileEnterprise tAutomobileEnterprise)
    {
        return toAjax(tAutomobileEnterpriseService.updateTAutomobileEnterprise(tAutomobileEnterprise));
    }

    /**
     * 删除车企信息
     */
    @Log(title = "车企信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tAutomobileEnterpriseService.deleteTAutomobileEnterpriseByIds(ids));
    }
}
